[libvirt] [PATCH] Rename 'remove' param to 'toremove' to avoid clash with Win32 header

Daniel P. Berrange berrange at redhat.com
Tue Nov 23 13:33:19 UTC 2010


The win32 headers have a function called 'remove' declared. This
clashes with the 'remove' parameter in virShrinkN

* src/util/memory.c: Rename 'remove' to 'toremove'
---
 src/util/memory.c |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/util/memory.c b/src/util/memory.c
index 96222db..f5061c0 100644
--- a/src/util/memory.c
+++ b/src/util/memory.c
@@ -237,18 +237,18 @@ int virResizeN(void *ptrptr, size_t size, size_t *allocptr, size_t count,
  * @ptrptr: pointer to pointer for address of allocated memory
  * @size: number of bytes per element
  * @countptr: pointer to number of elements in array
  * @remove: number of elements to remove
  *
  * Resize the block of memory in 'ptrptr' to be an array of
  * '*countptr' - 'remove' elements, each 'size' bytes in length.
  * Update 'ptrptr' and 'countptr'  with the details of the newly
  * allocated memory. If 'remove' is larger than 'countptr', free
  * the entire array.
  */
-void virShrinkN(void *ptrptr, size_t size, size_t *countptr, size_t remove)
+void virShrinkN(void *ptrptr, size_t size, size_t *countptr, size_t toremove)
 {
-    if (remove < *countptr)
-        ignore_value(virReallocN(ptrptr, size, *countptr -= remove));
+    if (toremove < *countptr)
+        ignore_value(virReallocN(ptrptr, size, *countptr -= toremove));
     else {
         virFree(ptrptr);
         *countptr = 0;
@@ -237,18 +237,18 @@ int virResizeN(void *ptrptr, size_t size, size_t *allocptr, size_t count,
  * @size: number of bytes per element
  * @countptr: pointer to number of elements in array
- * @remove: number of elements to remove
+ * @toremove: number of elements to remove
  *
  * Resize the block of memory in 'ptrptr' to be an array of
@@ -237,18 +237,18 @@ int virResizeN(void *ptrptr, size_t size, size_t *allocptr, size_t count,
  *
  * Resize the block of memory in 'ptrptr' to be an array of
- * '*countptr' - 'remove' elements, each 'size' bytes in length.
+ * '*countptr' - 'toremove' elements, each 'size' bytes in length.
  * Update 'ptrptr' and 'countptr'  with the details of the newly
@@ -237,18 +237,18 @@ int virResizeN(void *ptrptr, size_t size, size_t *allocptr, size_t count,
  * Update 'ptrptr' and 'countptr'  with the details of the newly
- * allocated memory. If 'remove' is larger than 'countptr', free
+ * allocated memory. If 'toremove' is larger than 'countptr', free
  * the entire array.
  */
-- 
1.7.2.3




More information about the libvir-list mailing list